import { fetchAPI } from './api';

enum MountPointTypeEnum {
	EMPTY = '',
	BIND = 'bind',
	VOLUME = 'volume',
	TMPFS = 'tmpfs',
	NPIPE = 'npipe',
	CLUSTER = 'cluster'
}

interface MountPoint {
	Type?: MountPointTypeEnum;
	Name?: string;
	Source?: string;
	Destination?: string;
	Driver?: string;
	Mode?: string;
	RW?: boolean;
	Propagation?: string;
}

export interface ContainerInfo {
	id: string;
	name: string;
	state: string;
	image: string;
	image_id: string;
	created_at: string;
	volumes?: MountPoint[];
	env?: string[];
	labels?: Record<string, string>;
}

export async function getContainerList(): Promise<ContainerInfo[]> {
	const res = await fetchAPI('/containers');
	return res.json();
}

export async function getContainerInfo(name: string): Promise<ContainerInfo> {
	const res = await fetchAPI(`/containers/${name}`);
	return res.json();
}

export async function getContainerLogs(name: string): Promise<string> {
	const res = await fetchAPI(`/containers/${name}/logs`);
	return res.text();
}
