import { fetchAPI } from './api';

interface NetworkInterface {
	name: string;
	received: number;
	transmitted: number;
}

interface DiskInfo {
	device_name: string;
	mount_point: string;
	total_space: number;
	available_space: number;
}

export interface SystemInfo {
	// Node info
	name: string;
	host_name: string;
	os_version: string;
	kernel_version: string;

	// RAM usage
	total_memory: number;
	used_memory: number;
	total_swap: number;
	used_swap: number;

	// Multi-elem resources
	networks: NetworkInterface[];
	disks: DiskInfo[];

	// CPU
	cpu_count: number;
	load_average: [number, number, number];
}

export async function getSystemInfo(): Promise<SystemInfo> {
	const res = await fetchAPI('/system-info');
	return res.json();
}
