import { env } from '$env/dynamic/private';
import EventSource from 'eventsource';

// Proxy the streaming logs from serverman
export async function GET({ params }) {
	let logSource: EventSource;
	let closed = false;

	const stream = new ReadableStream({
		start(controller) {
			logSource = new EventSource(`${env.SERVERMAN_BASE_URL}/containers/${params.name}/logs`);

			logSource.addEventListener('message', (ev) => {
				if (closed) {
					logSource.close();
					return;
				}

				try {
					controller.enqueue(`data: ${ev.data}\n\n`);
				} catch (e) {
					console.error(e);
				}
			});

			logSource.addEventListener('error', (ev) => {
				closed = true;

				try {
					controller.close();
				} catch (e) {
					console.error(e);
				}
			});
		},
		cancel() {
			logSource.close();
		}
	});

	return new Response(stream, {
		headers: {
			'Content-Type': 'text/event-stream',
			'Cache-Control': 'no-cache'
		}
	});
}
